local assets=
{
	Asset("ANIM", "anim/iceblade.zip"),
	Asset("ANIM", "anim/swap_iceblade.zip"),
 Asset("IMAGE", "images/inventoryimages/iceblade.tex"),
 Asset("ATLAS", "images/inventoryimages/iceblade.xml"),
}

local function perish(inst)
    inst:Remove()
end

local function onequip(inst, owner)
    owner.AnimState:OverrideSymbol("swap_object", "swap_iceblade", "swap_nightmaresword")
    owner.AnimState:Show("ARM_carry")
    owner.AnimState:Hide("ARM_normal")
end

local function onunequip(inst, owner)
    owner.AnimState:Hide("ARM_carry")
    owner.AnimState:Show("ARM_normal")
end

local function onattack(inst, attacker, target)
    if target.components.freezable then
        target.components.freezable:AddColdness(TUNING.ICEBLADEFREEZE)
    end
    if target.components.sleeper and target.components.sleeper:IsAsleep() then
        target.components.sleeper:WakeUp()
    end
    if target.components.burnable and target.components.burnable:IsBurning() then
        target.components.burnable:Extinguish()
    end
    if target.components.combat then
        target.components.combat:SuggestTarget(attacker)
        if target.sg and not target.sg:HasStateTag("frozen") and target.sg.sg.states.hit then
            target.sg:GoToState("hit")
        end
    end
end

local function fn(Sim)
	local inst = CreateEntity()
	local trans = inst.entity:AddTransform()
	local anim = inst.entity:AddAnimState()
    MakeInventoryPhysics(inst)
    
    inst.AnimState:SetBank("nightmaresword")
    inst.AnimState:SetBuild("iceblade")
    inst.AnimState:PlayAnimation("idle")
    inst.AnimState:SetMultColour(1, 1, 1, 1)
    
    inst:AddTag("sharp")
    
	inst:AddComponent("weapon")
    inst.components.weapon:SetDamage(TUNING.ICEBLADEDMG)
    inst.components.weapon:SetOnAttack(onattack)
    
    
            inst:AddComponent("perishable")
        inst.components.perishable:SetPerishTime(TUNING.PERISH_ONE_DAY*TUNING.ICEBLADEDURATION)
        inst.components.perishable:StartPerishing()
        inst.components.perishable:SetOnPerishFn(perish)

 
    inst:AddComponent("heater")
    inst.components.heater.iscooler = true
    inst.components.heater.equippedheat = TUNING.BLUEGEM_COOLER
 
    inst:AddComponent("inspectable")
    
    inst:AddComponent("repairable")
    inst.components.repairable.repairmaterial = "ICE"
    inst.components.repairable.announcecanfix = true

    inst:AddComponent("inventoryitem")
    inst.components.inventoryitem.atlasname = "images/inventoryimages/iceblade.xml"
    
    inst:AddComponent("equippable")
    inst.components.equippable:SetOnEquip( onequip )
    inst.components.equippable:SetOnUnequip( onunequip )
    inst.components.equippable.equippedmoisture = 1
    inst.components.equippable.maxequippedmoisture = 35-- Meter reading rounds up, so set 1 below
    inst.components.equippable.insulated = true
    inst.components.equippable.dapperness = TUNING.CRAZINESS_SMALL
    inst:AddTag("show_spoilage")
    inst:AddTag("frozen")
        return inst
end

return Prefab( "common/inventory/iceblade", fn, assets)